package uniandes.apo2h.cupiFitCenter.interfaz;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ImageIcon;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import uniandes.apo2h.utiles.CriteriosOrdenBusqueda;
/**
 * Barra de opciones
 * @author alvar-go
 *
 */
public class BarraOpciones extends JMenuBar implements ActionListener
{
	/**
	 * Ruta de los iconos de la barra
	 */
	public final static String RUTA_ICONOS = "data/iconos/";
	
	/**
	 * comando para agregar ciudad
	 */
	public final static String AGREGAR_CIUDAD = "Agragar ciudad";
	
	/**
	 * Comando para agregar gimnasio
	 */
	public final static String AGREGAR_GIMANSIO = "Agregar gimnasio";
	
	/**
	 * Comando para editar gimnasio
	 */
	public final static String EDITAR_GIMNASIO = "Editar gimnasio";
	
	/**
	 * Menu con funciones de ciudades
	 */
	private JMenu menuCiudadades;
	
	/**
	 * item para agregar ciudad
	 */
	private JMenuItem itemAgregarCiudad;
		
	/**
	 * men con funciones de gimnasios
	 */
	private JMenu menuGimnasios;
	
	/**
	 * item para agregar gimnasio
	 */
    private JMenuItem itemAgregarGimnasio;
	
    /**
     * item para editar gimnasio
     */
	private JMenuItem itemEditarGimnasio;
	
	/**
	 * Menu para ordenar gimnasios
	 */
	private JMenu menuOrdenarGimnasios;
	
	/**
	 * Men para ordenar gimnasios ascendentemente
	 */
	private JMenu menuOrdenarGimnasiosAsc;
	
	/**
	 * Men para ordenar gimansios descendentemente
	 */
	private JMenu menuOrdenarGimnasiosDesc;
	
	/**
	 * item para eliminar gimnasios
	 */
	private JMenuItem itemEliminarGimnasio;
	
	/**
	 * men para buscar gimnasios
	 */
	private JMenu menuBuscarGimnasios;
	
	/**
	 * Clase principal
	 */
	private InterfazCupifitCenter principal;
	
	/**
	 * Crea la barra de opciones
	 * @param interfaz clase principal. interfaz != null
	 */
	public BarraOpciones(InterfazCupifitCenter interfaz)
	{
		principal = interfaz;
		
		menuCiudadades = new JMenu("Ciudades");
		menuCiudadades.setIcon(new ImageIcon(RUTA_ICONOS + "ciudades.png"));
		add(menuCiudadades);
		
		itemAgregarCiudad = new JMenuItem("Agregar ciudad");
		itemAgregarCiudad.setActionCommand(AGREGAR_CIUDAD);
		itemAgregarCiudad.addActionListener(this);
		itemAgregarCiudad.setIcon(new ImageIcon(RUTA_ICONOS + "agregar.png"));
		itemAgregarCiudad.addActionListener(this);
		menuCiudadades.add(itemAgregarCiudad);
		
		menuGimnasios = new JMenu("Gimnasios");
		menuGimnasios.setIcon(new ImageIcon(RUTA_ICONOS + "gimnasios.png"));
		add(menuGimnasios);
		
		itemAgregarGimnasio = new JMenuItem("Agregar gimnasio");
		itemAgregarGimnasio.setActionCommand(AGREGAR_GIMANSIO);
		itemAgregarGimnasio.addActionListener(this);
		itemAgregarGimnasio.setEnabled(false);
		itemAgregarGimnasio.setIcon(new ImageIcon(RUTA_ICONOS + "agregar.png"));
		menuGimnasios.add(itemAgregarGimnasio);
		
		itemEditarGimnasio = new JMenuItem("Editar gimnasio");
		itemEditarGimnasio.setActionCommand(EDITAR_GIMNASIO);
		itemEditarGimnasio.addActionListener(this);
		itemEditarGimnasio.setIcon(new ImageIcon(RUTA_ICONOS + "editar.png"));
		menuGimnasios.add(itemEditarGimnasio);
		
		menuOrdenarGimnasios = new JMenu("Ordenar gimnasios");
		menuOrdenarGimnasios.setIcon(new ImageIcon(RUTA_ICONOS + "ordenar.png"));
		menuGimnasios.add(menuOrdenarGimnasios);
		
		menuOrdenarGimnasiosAsc = new JMenu("Ordenar Ascendentemente");
		menuOrdenarGimnasiosAsc.setIcon(new ImageIcon(RUTA_ICONOS + "ascendente.jpg"));
		menuOrdenarGimnasios.add(menuOrdenarGimnasiosAsc);
		
		for (CriteriosOrdenBusqueda c: CriteriosOrdenBusqueda.values()) {
			JMenuItem item =  new JMenuItem(c.getNombre());
			item.addActionListener(this);
			item.setActionCommand("O_ASC_"+c.name());
			menuOrdenarGimnasiosAsc.add(item);
		}
		
		menuOrdenarGimnasiosDesc = new JMenu("Ordenar Descendentemente");
		menuOrdenarGimnasiosDesc.setIcon(new ImageIcon(RUTA_ICONOS + "descendente.jpg"));
		menuOrdenarGimnasios.add(menuOrdenarGimnasiosDesc);
		
		for (CriteriosOrdenBusqueda c: CriteriosOrdenBusqueda.values()) {
			JMenuItem item =  new JMenuItem(c.getNombre());
			item.addActionListener(this);
			item.setActionCommand("O_DESC_"+c.name());
			menuOrdenarGimnasiosDesc.add(item);
		}
				
		itemEliminarGimnasio = new JMenuItem("Eliminar gimnasio");
		itemEliminarGimnasio.setEnabled(false);
		itemEliminarGimnasio.addActionListener(this);
		itemEliminarGimnasio.setIcon(new ImageIcon(RUTA_ICONOS + "eliminar.png"));
		menuGimnasios.add(itemEliminarGimnasio);
		
		menuBuscarGimnasios = new JMenu("Buscar");
		menuBuscarGimnasios.setIcon(new ImageIcon(RUTA_ICONOS + "buscar.png"));
		menuGimnasios.add(menuBuscarGimnasios);
		
		for (CriteriosOrdenBusqueda c: CriteriosOrdenBusqueda.values()) {
			JMenuItem item =  new JMenuItem(c.getNombre());
			item.addActionListener(this);
			item.setActionCommand("B_"+c.name());
			menuBuscarGimnasios.add(item);
		}
				
		
		
	}

	public void actionPerformed(ActionEvent e) 
	{
		String comando = e.getActionCommand();
		if(comando.equals(AGREGAR_CIUDAD))
		{
			principal.agregarCiudad();
		}
		else if(comando.equals(AGREGAR_GIMANSIO))
		{
			//No se implementar
		}
		else if(comando.equals(EDITAR_GIMNASIO))
		{
			principal.editarGimnasio();
		}
		else 
		{
			String[] partes = comando.split("_");
			if(partes[0].equals("O"))
			{
				if(partes[1].equals("ASC"))
				{
					principal.ordenar(CriteriosOrdenBusqueda.valueOf(partes[2]), true);
				}
				else
				{
					principal.ordenar(CriteriosOrdenBusqueda.valueOf(partes[2]), false);
				}
			}
			else if(partes[0].equals("B"))
			{
				principal.buscar(CriteriosOrdenBusqueda.valueOf(partes[1]));
			}
		}
		
	}
}
