package uniandes.apo2h.cupiFitCenter.interfaz;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import uniandes.apo2h.cupiFitCenter.mundo.*;
import uniandes.apo2h.utiles.Buscador;
import uniandes.apo2h.utiles.CriteriosOrdenBusqueda;
import uniandes.apo2h.utiles.Ordenador;
import uniandes.apo2h.utiles.Ordenamientos;

/**
 * Clase principal de la aplicacin
 * @author alvar-go
 *
 */
public class InterfazCupifitCenter extends JFrame
{
	/**
	 * ruta iconos de los tabs
	 */
	public final static String RUTA_TABS = "data/tabs/";
	
	/**
	 * Barra de opciones
	 */
	private BarraOpciones opciones;
	
	/**
	 * tabs de la aplicacin
	 */
	private JTabbedPane panelTabs;
	
	/**
	 * Panel con informacin de la ciudad
	 */
	private PanelCiudad panelCiudad;
	
	/**
	 * Panel con informacin del gimnasio
	 */
	private PanelGimnasio panelGimnasio;
	
	/**
	 * Clase principal del mundo
	 */
	private CupiFitCenter mundo;
	
	/**
	 * Buscador de gimnasios
	 */
	private Buscador<Gimnasio> buscadorGimnasio;
	
	/**
	 * Ordenador de gimnasios
	 */
	private Ordenador<Gimnasio> ordenadorGimnasio;
	
	/**
	 * Crea la ventana principal
	 */
	public InterfazCupifitCenter()
	{
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setResizable(false);
		setTitle("CupiFitCenter");
		Dimension pantalla = getToolkit().getScreenSize();
		setSize(pantalla.width/2, pantalla.height-40);
		setLayout(new BorderLayout());
		
		opciones = new BarraOpciones(this);
		setJMenuBar(opciones);
		
		panelTabs = new JTabbedPane();
		
		
		JPanel panelCiudadGimnasio = new JPanel(new BorderLayout());
		
		panelTabs.addTab("Ciudades - Gimnasios - Zonas - Equipos", new ImageIcon(RUTA_TABS + "gimnasio.png"), panelCiudadGimnasio, "Permite administrar ciudades, gimnasios, zonas y equipos.");
		add(panelTabs, BorderLayout.CENTER);
		
		panelCiudad = new PanelCiudad(this);
		panelCiudadGimnasio.add(panelCiudad, BorderLayout.NORTH);	
		
		panelGimnasio = new PanelGimnasio();
		panelCiudadGimnasio.add(panelGimnasio, BorderLayout.CENTER);
		
		setLocationRelativeTo(null);
		
		
		
		mundo = new CupiFitCenter();
		cargarGimansios();
		panelCiudad.actualizar(mundo.getCiudades());
		actualizar(panelCiudad.darSeleccionado());
		
		
		//TODO inicialice el ordenador y el buscador

		
	}
	
	/**
	 * Agrega una ciudad al CFC
	 */
	public void agregarCiudad()
	{
		String nombre = (String) JOptionPane.showInputDialog(this, "Ingrese el nombre de la ciudad", "Agregar Ciudad", JOptionPane.DEFAULT_OPTION, new ImageIcon("data/iconos/agregar.png"), null, null);
		Ciudad ciudad = new Ciudad(nombre);
		try 
		{
			mundo.addCiudad(ciudad);
			panelCiudad.actualizar(mundo.getCiudades());
			panelCiudad.cambiarSeleccion(ciudad);
			actualizar(ciudad);
		} 
		catch (Exception e) 
		{
			JOptionPane.showMessageDialog(this, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE, new ImageIcon("data/iconos/error.png"));
		}
	}
	
	/**
	 * Activa la edicin de un gimnasio
	 */
	public void editarGimnasio() {
		panelGimnasio.activarParaEdicion();
	}
	
	/**
	 * Ordena los gimnasios de acuerdo a un criterio
	 * @param criterio criterio de orden
	 * @param ascendente true si es ascendente o false en caso contrario
	 */
	public void ordenar(CriteriosOrdenBusqueda criterio, boolean ascendente) {
		Ordenamientos s = (Ordenamientos)JOptionPane.showInputDialog(this,"Seleccione el algoritmo","Algoritmo", JOptionPane.PLAIN_MESSAGE, new ImageIcon(""),
		                    Ordenamientos.values(),Ordenamientos.BURBUJA);
		//TODO user el mtodo ordenador para ordenar la lista de gimnasios de la ciudad actual
		
		
		panelGimnasio.actualizarLista( panelCiudad.darSeleccionado().getGimnasios(), 0);
		
	}
	
	/**
	 * Busca gimnasios de acuerdo a un criterio
	 * @param criterio el criterio de busqueda
	 */
	public void buscar(CriteriosOrdenBusqueda criterio) {
		String[] opciones = new String[]{"Mayor", "Menor"};
		String s = (String)JOptionPane.showInputDialog(this,"Seleccione el tipo de busqueda","Busqeuda", JOptionPane.PLAIN_MESSAGE, new ImageIcon(""),
                opciones,opciones[0]);

		//TODO use el mtodo buscar mayor y buscar menor para buscar segn el criterio dado
		
		
	}
	
	/**
	 * Actualiza la visualizacin con la ciudad seleccionada
	 * @param ciudad ciudad seleccionada
	 */
	public void actualizar(Ciudad ciudad) 
	{
		if(ciudad != null)
		{
			panelGimnasio.actualizarLista(ciudad.getGimnasios(), 0);
			panelCiudad.actualizarCantidad(ciudad.getGimnasios().size());
		}
		
	}

	public static void main(String[] args) 
	{
		InterfazCupifitCenter interfaz = new InterfazCupifitCenter();
		interfaz.setVisible(true);
	}

	/**
	 * Carga los gimnasios
	 */
	private void cargarGimansios()
	{
		try {
			File f = new File("data/gimnasios.properties");
			FileInputStream in = new FileInputStream(f);
			Properties p = new Properties();
			p.load(in);
			in.close();
			
			Horario[] hs = new Horario[7];
			int m = 0;
			for(Dias d: Dias.values())
			{
				hs[m] = new Horario(d, new int[]{7,0}, new int[]{21,0});
				m++;
			}
			
			int ciudades = Integer.parseInt(p.getProperty("ciudades").trim());
			for (int i = 1; i <= ciudades; i++) {
				Ciudad c = new Ciudad(p.getProperty("ciudad" + i + ".nombre").trim());
				mundo.addCiudad(c);
				int gimnasios  = Integer.parseInt(p.getProperty("ciudad"+i+".gimnasios").trim());

				for (int j = 1; j <= gimnasios; j++) 
				{
					String nombre = p.getProperty("gimnasio"+i+"-"+j+".nombre");
					String direccion = p.getProperty("gimnasio"+i+"-"+j+".direccion");
					Categorias categoria = Categorias.valueOf(p.getProperty("gimnasio"+i+"-"+j+".categoria"));
					int capacidad = Integer.parseInt(p.getProperty("gimnasio"+i+"-"+j+".capacidad"));
					String imagen = p.getProperty("gimnasio"+i+"-"+j+".imagen");
					Gimnasio g = new Gimnasio(nombre, direccion, hs, categoria, capacidad, imagen);
					c.addGimnasio(g);
				}
			}
		} 
		catch (Exception e) {
			JOptionPane.showMessageDialog(this, "Problema cargando los gimnasios\n" + e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE, new ImageIcon("data/iconos/error.png"));
		}
	}

	

}
