package uniandes.apo2h.cupiFitCenter.mundo;

import java.util.ArrayList;
import java.util.List;

/**
 * Clase que representa una ciudad
 * @author alvar-go
 *
 */
public class Ciudad 
{

	/**
	 * el nombre de la ciudad
	 */
	private String nombre;
	
	/**
	 * gimnasios de la ciudad
	 */
	private List<Gimnasio> gimnasios;

	
	/**
	 * Crea una ciudad a patir de sus datos bsicos
	 * post: la lista de gimnasios se ha incializado
	 * @param nombre el nombre de la ciudad. nombre != null && nombre != ""
	 */
	public Ciudad(String nombre) {
		this.nombre = nombre;
		gimnasios = new ArrayList<Gimnasio>();
	}

	/**
	 * Devuelve el nombre de la ciudad
	 * @return nombre
	 */
	public String getNombre() {
		return nombre;
	}
	
	/**
	 * devuelve la lista de gimnasios de la ciudad
	 * @return gimnasios
	 */
	public List<Gimnasio> getGimnasios()
	{
		return gimnasios;
	}
	
	/**
	 * Agrega un gimnasio a la ciudad
	 * pre: la lista de gimnasios se encuentra creada
	 * @param gimnasio el gimnasio que se desea agregar. gimnasio != null
	 * @throws Exception Se lanza en caso que ya exista un gimnasio con el nombre del que se desea agregar
	 */
	public void addGimnasio(Gimnasio gimnasio) throws Exception
	{
		if(!gimnasios.contains(gimnasio))
		{
			gimnasios.add(gimnasio);
		}
		else
		{
			throw new Exception("Ya existe el gimnasio: " + gimnasio.getNombre());
		}
	}

	/**
	 * Modifica el nombre de la ciudad
	 * @param nombre el nuevo nombre de la ciudad. nombre != null & nombre != ""
	 */
	public void setNombre(String nombre) {
		this.nombre = nombre;
	}
	
	/**
	 * Indica si la ciudad es igual a otra. Dos ciudades son iguales si tiene el mismo nombre
	 * @return true si las dos ciudades son iguales o false en caso contrario
	 * 
	 */
	public boolean equals(Object ciudad)
	{
		if(ciudad != null)
		{
			try {
				return nombre.equals(((Ciudad)ciudad).getNombre());
			}
			catch (Exception e) 
			{
				return false;
			}
		}
		else
		{
			return false;
		}
	}
	
}
