package uniandes.apo2h.cupiFitCenter.mundo;

/**
 * Clase que representa un gimnasio sede de CupiFitCenter
 * @author alvar-go
 *
 */
public class Gimnasio 
{
	/**
	 * Cantidad de das que debe abrir la sede
	 */
	public final static int CANTIDAD_HORARIOS = 7;
	
	/**
	 * Nombre de la sede
	 */
	private String nombre;
	
	/**
	 * Direccin de la sede
	 */
	private String direccion;
	
	/**
	 * Horarios de la sede
	 */
	private Horario[] horarios;
	
	/**
	 * categoria de la sede
	 */
	private Categorias categoria;
	
	/**
	 * capacidad de personas de la sede
	 */
	private int capacidad;
	
	/**
	 * Imagen de la sede
	 */
	private String imagen;

	/**
	 * Crea un nuevo gimnasio a partir de sus datos bsicos
	 * @param nombre el nombre del gimansio. nombre != null && nombre != ""
	 * @param direccion la direccin del gimnasio. direccin != null && direccin != ""
	 * @param horarios horarios en que atiende la sede. gimnasios != null
	 * @param categoria la categoria del gimansio. categoria != null
	 * @param capacidad la capacidad de personas del gimnasio. capacidad > 0
	 * @param imagen la imagen del gimansio.
	 */
	public Gimnasio(String nombre, String direccion, Horario[] horarios, Categorias categoria, int capacidad, String imagen) {
		super();
		this.nombre = nombre;
		this.direccion = direccion;
		this.horarios = horarios;
		this.categoria = categoria;
		this.imagen = imagen;
		this.capacidad = capacidad;
	}

	/**
	 * Devuelve el nombre del gimnasio
	 * @return nombre
	 */
	public String getNombre() {
		return nombre;
	}

	/**
	 * Devuelve la direccin del gimnasio
	 * @return direccion
	 */
	public String getDireccion() {
		return direccion;
	}

	/**
	 * Devuelve los horarios de atencipn del gimnasio
	 * @return horarios
	 */
	public Horario[] getHorarios() {
		return horarios;
	}


	/**
	 * Devuelve la categoria del gimansio
	 * @return categoria
	 */
	public Categorias getCategoria() {
		return categoria;
	}
	
	/**
	 * Devuelve la capacidad del gimnasio
	 * @return capacidad
	 */
	public int getCapacidad() {
		return capacidad;
	}
	
	/**
	 * Devuelve la imagen del gimnasio
	 * @return imagen
	 */
	public String getImagen() {
		return imagen;
	}
	

	/**
	 * Modifica el nombre del gimnasio
	 * @param nombre el nuevo nombre del gimnasio. nombre != null && nombre != ""
	 */
	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	/**
	 * Modifica la direccin del gimnasio
	 * @param direccion la nueva direccin del gimnasio. direccion != null && direccion != ""
	 */
	public void setDireccion(String direccion) {
		this.direccion = direccion;
	}

	/**
	 * Modifica los horarios de atencin del gimnasio
	 * @param horarios los nuevos horarios del gimnasio. horarios != null
	 */
	public void setHorarios(Horario[] horarios) {
		this.horarios = horarios;
	}

	/**
	 * Modifica la capacidad del gimnasio
	 * @param capacidad la nueva capacidad del gimnasio. capacidad > 0
	 */
    public void setCapacidad(int capacidad)
    {
    	this.capacidad = capacidad;
    }

    /**
     * Modifica la categoria del gimnasio
     * @param categoria la nueva categoria del gimnasio. categoria != null
     */
	public void setCategoria(Categorias categoria) {
		this.categoria = categoria;
	}

	/**
	 * Modifica la imagen del gimnasio
	 * @param imagen la nueva imagen del gimnasio
	 */
	public void setImagen(String imagen) {
		this.imagen = imagen;
	}
	
	
	/**
	 * Indica si el gimnasio es igual a otro. Dos gimnasios son iguales si tiene el mismo nombre
	 * @return true si los dos gimnasios son iguales o false en caso contrario
	 * 
	 */
	public boolean equals(Object gimnasio)
	{
		if(gimnasio != null)
		{
			try {
				return nombre.equals(((Gimnasio)gimnasio).getNombre());
			}
			catch (Exception e) 
			{
				return false;
			}
		}
		else
		{
			return false;
		}
	}
	
	
}
