package uniandes.apo2h.cupiFitCenter.mundo;

/**
 * Clase que representa un horario
 * @author alvar-go
 *
 */
public class Horario 
{

	/**
	 * Dia de la semana del horario
	 */
	private Dias dia;
	
	/**
	 * Hora de inicio del horario {hh,mm}
	 */
	private int[] horaInicio;
	
	/**
	 * Hora de fin del horario {hh,mm}
	 */
	private int[] horaFin;
	
	/**
	 * Crea un nuevo horario a partir de sus datos bsicos
	 * @param dia el da del horario. dia != null
	 * @param horaInicio la hora de inicio. horaInicio en la forma {hh,mm}
	 * @param horaFin la hora de fin. horaFin en la forma {hh,mm} 
	 */
	public Horario(Dias dia, int[] horaInicio, int[] horaFin) {

		this.dia = dia;
		this.horaInicio = horaInicio;
		this.horaFin = horaFin;
	}

	/**
	 * Devuelve el da del horario
	 * @return dia
	 */
	public Dias getDia() 
	{
		return dia;
	}

	/**
	 * Devuelve la hora de inicio del horario
	 * @return horaInicio
	 */
	public int[] getHoraInicio() 
	{
		return horaInicio;
	}

	/**
	 * Devuelve la hora de fin del horario
	 * @return horaFin
	 */
	public int[] getHoraFin() 
	{
		return horaFin;
	}
	

	public String getHoraInicioToString() 
	{
		return horaInicio[0]+":"+(horaInicio[1]<10?"0"+horaInicio[1]:horaInicio[1]);
	}

	/**
	 * Devuelve la hora de fin del horario
	 * @return horaFin
	 */
	public String getHoraFinToString() 
	{
		return  horaFin[0]+":"+(horaFin[1]<10?"0"+horaFin[1]:horaFin[1]);
	}

	/**
	 * Cambia el dia del horario
	 * @param dia el nuevo dia del horario. dia != null
	 */
	public void setDia(Dias dia) 
	{
		this.dia = dia;
	}

	/**
	 * Cambia la hora de inicio del horario
	 * @param horaInicio la nueva hora de inicio. horaInicio en la forma {hh,mm}
	 */
	public void setHoraInicio(int[] horaInicio) 
	{
		this.horaInicio = horaInicio;
	}

	/**
	 * Cambia la hora de fin del horario
	 * @param horaFin la nueva hora de fin. horaFin en la forma {hh,mm}
	 */
	public void setHoraFin(int[] horaFin) 
	{
		this.horaFin = horaFin;
	}
}
