package uniandes.apo2h.utiles;

import java.util.Comparator;

import uniandes.apo2h.cupiFitCenter.mundo.*;

/**
 * Enumeracin de criterios de comparacin disponibles para los gimnasios
 * @author alvar-go
 *
 */
public enum CriteriosOrdenBusqueda {

	CAPACIDAD("Capacidad", new ComparadorGimansioCapacidad()),
	DIRECCION("Direccin", new ComparadorGimansioDireccion()),
	CATEGORIA("Exclusividad de categora", new ComparadorGimansioExclusividadCategoria()),
	NOMBRE("Nombre", new ComparadorGimansioNombre());
	
	/**
	 * Nombre del criterios
	 */
	private String nombre;
	
	/**
	 * Comaprador asociado al criterio
	 */
	private Comparator<Gimnasio> comparador;
	
	/**
	 * crea un criterio de comparacin a partir de sus datos bsicos
	 * @param nombre el nombre del criterio. nombre != null && nombre != ""
	 * @param comparador comparador asociado al criterio. comaprador != null
	 */
	private CriteriosOrdenBusqueda(String nombre, Comparator<Gimnasio> comparador)
	{
		this.nombre = nombre;
		this.comparador = comparador;
	}

	/**
	 * Devuelve el nombre el criterio
	 * @return nombre
	 */
	public String getNombre() {
		return nombre;
	}

	/**
	 * Devuelve el comparador asociado al criterio
	 * @return comparador
	 */
	public Comparator<Gimnasio> getComparador() {
		return comparador;
	}
	
	/**
	 * Devuelve la rerpresentacin en String del criterio
	 * @return <nombre>
	 */
	public String toString(){
		return nombre;
	}	
}
