package uniandes.apo2h.mundo.test;

import java.util.List;

import junit.framework.TestCase;
import uniandes.apo2h.cupiFitCenter.mundo.Ciudad;
import uniandes.apo2h.cupiFitCenter.mundo.CupiFitCenter;

/**
 * Clase que prueba el CupiFitCenter
 * @author alvar-go
 *
 */
public class CupiFitCenterTest extends TestCase {

	/**
	 * Clase a probar
	 */
	private CupiFitCenter cupiFitCenter;
	
	/**
	 * Crea el escenario de pruebas
	 */
	public void setUp()
	{
		cupiFitCenter = new CupiFitCenter();
		try {
			cupiFitCenter.addCiudad(new Ciudad("Bogot"));
			cupiFitCenter.addCiudad(new Ciudad("Medellin"));
			cupiFitCenter.addCiudad(new Ciudad("Cali"));
			cupiFitCenter.addCiudad(new Ciudad("Cartagena"));
			
		} catch (Exception e) {
			//No debera ocurrir
		}
	}
	
	/**
     * Prueba 1: Se encarga de verificar el mtodo getCiduades de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getCiduades<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se registraron todas las ciudades del escenario.<br>
     * 2. Las ciudades se registraron correctamente en el orden que fueron agragadas.<br>
     */
	public void testGetCiudades() {
		List<Ciudad> ciudades = cupiFitCenter.getCiudades();
		assertEquals("La cantidad de ciudades es incorrecta", 4, ciudades.size());
		assertEquals("La ciudad  1 es incorrecta", "Bogot", ciudades.get(0).getNombre());
		assertEquals("La ciudad  2 es incorrecta", "Medellin", ciudades.get(1).getNombre());
		assertEquals("La ciudad  3 es incorrecta", "Cali", ciudades.get(2).getNombre());
		assertEquals("La ciudad  4 es incorrecta", "Cartagena", ciudades.get(3).getNombre());
	}
	
	/**
     * Prueba 2: Se encarga de verificar el mtodo addCiudad de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * addCiudad<br>
     * <b> Casos de prueba:</b><br>
     * 1. Si la ciudad no existe se registra.<br>
     * 2. Si la ciudad existe se lanza una excepcin.<br>
     */
	public void testAddCiudad() 
	{
		try {
			cupiFitCenter.addCiudad(new Ciudad("Pasto"));
		} catch (Exception e) {
			fail("No debera ocurrir la excepcin");
		}
		
		try {
			cupiFitCenter.addCiudad(new Ciudad("Cali"));
			fail("Debera ocurrir la excepcin");
		} catch (Exception e) {
			//Debe ocurrir
		}
	}
	
	
}
