package uniandes.apo2h.mundo.test;

import junit.framework.TestCase;
import uniandes.apo2h.cupiFitCenter.mundo.Categorias;
import uniandes.apo2h.cupiFitCenter.mundo.Dias;
import uniandes.apo2h.cupiFitCenter.mundo.Gimnasio;
import uniandes.apo2h.cupiFitCenter.mundo.Horario;

/**
 * Clase que prueba el funcionamiento del gimnasio
 * @author alvar-go
 *
 */
public class GimnasioTest extends TestCase{

	/**
	 * Clase a probar
	 */
	private Gimnasio gimnasio;
	
	/**
	 * Prepara el escenario de pruebas
	 */
	public void setUp(){
		
		Horario[] hs = new Horario[Gimnasio.CANTIDAD_HORARIOS];
		int i = 0;
		for(Dias d: Dias.values())
		{
			hs[i] = new Horario(d, new int[]{7,0}, new int[]{21,0});
			i++;
		}
		gimnasio = new Gimnasio("Calle 135", "Autopista # 135", hs, Categorias.PREMIUM, 10, "data/images.jpg");
		
	}
	

    /**
     * Prueba 1: Se encarga de verificar el mtodo getNombre de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getNombre<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente el nombre al gimnasio.<br>
     */
	public void testGetNombre() {
		assertEquals("El nombre no se asign correctamente", "Calle 135", gimnasio.getNombre());
	}


    /**
     * Prueba 2: Se encarga de verificar el mtodo getDrieccion de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getDireccion<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la direccin al gimnasio.<br>
     */
	public void testGetDireccion() {
		assertEquals("La direccin no se asign correctamente", "Autopista # 135", gimnasio.getDireccion());
	}


    /**
     * Prueba 3: Se encarga de verificar el mtodo getHorarios de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getDireccion<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente el horario de atencin al gimnasio.<br>
     */
	public void testGetHorarios() {
		Horario[] hs = gimnasio.getHorarios();
		assertEquals("El horario no se asign correctamente", Dias.L, hs[0].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[0].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[0].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.M, hs[1].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[1].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[1].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.I, hs[2].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[2].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[2].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.J, hs[3].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[3].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[3].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.V, hs[4].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[4].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[4].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.S, hs[5].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[5].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[5].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.D, hs[6].getDia());
		assertEquals("El horario no se asign correctamente", "7:00", hs[6].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "21:00", hs[6].getHoraFinToString());
		
	}


	/**
     * Prueba 4: Se encarga de verificar el mtodo getCategoria de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getCategoria<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la categoria al gimnasio.<br>
     */
	public void testGetCategoria() {
		
		//TODO Complete segn la documentacin
		
	}
	

	/**
     * Prueba 5: Se encarga de verificar el mtodo getCapacidad de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getCapacidad<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la capacidad al gimnasio.<br>
     */
	public void testGetCapacidad() {
		//TODO Complete segn la documentacin
	}
	

	/**
     * Prueba 6: Se encarga de verificar el mtodo getImagen de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * getIamgen<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la imagen al gimnasio.<br>
     */
	public void testGetImagen() {
		//TODO Complete segn la documentacin
	}
	

	 /**
     * Prueba 7: Se encarga de verificar el mtodo setNombre de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * setNombre<br>
     * getNombre<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente el nombre al gimnasio.<br>
     */
	public void testSetNombre() {
		gimnasio.setNombre("otro nombre");
		assertEquals("El nombre no se asign correctamente", "otro nombre", gimnasio.getNombre());
		
	}

    /**
     * Prueba 8: Se encarga de verificar el mtodo setDireccion de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * setDireccion<br>
     * getDireccion<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la direccin al gimnasio.<br>
     */
	public void testSetDireccion() {
		//TODO Complete segn la documentacin
	}


	 /**
     * Prueba 9: Se encarga de verificar el mtodo setHorarios de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * setHorarios<br>
     * getHorarios<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente el horario de atencin al gimnasio.<br>
     */
	public void testSetHorarios() {

		Horario[] nuevos = new Horario[Gimnasio.CANTIDAD_HORARIOS];
		int i = 0;
		for(Dias d: Dias.values())
		{
			nuevos[i] = new Horario(d, new int[]{10,0}, new int[]{18,0});
			i++;
		}
		gimnasio.setHorarios(nuevos);
		Horario[] hs = gimnasio.getHorarios();
		assertEquals("El horario no se asign correctamente", Dias.L, hs[0].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[0].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[0].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.M, hs[1].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[1].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[1].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.I, hs[2].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[2].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[2].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.J, hs[3].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[3].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[3].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.V, hs[4].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[4].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[4].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.S, hs[5].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[5].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[5].getHoraFinToString());
		
		assertEquals("El horario no se asign correctamente", Dias.D, hs[6].getDia());
		assertEquals("El horario no se asign correctamente", "10:00", hs[6].getHoraInicioToString());
		assertEquals("El horario no se asign correctamente", "18:00", hs[6].getHoraFinToString());
	}


	/**
     * Prueba 10: Se encarga de verificar el mtodo setCapacidad de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * setCapacidad<br>
     * getCapacidad<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la capacidad al gimnasio.<br>
     */
    public void testSetCapacidad()
    {
    	//TODO Complete segn la documentacin
    }


    /**
     * Prueba 11: Se encarga de verificar el mtodo setCategoria de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * setCategoria<br>
     * getCategoria<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la categoria al gimnasio.<br>
     */
	public void testSetCategoria() {
		//TODO Complete segn la documentacin
	}


	/**
     * Prueba 6: Se encarga de verificar el mtodo setImagen de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * setIamgen<br>
     * getIamgen<br>
     * <b> Casos de prueba:</b><br>
     * 1. Se asign correctamente la imagen al gimnasio.<br>
     */
	public void testSetImagen() {
		//TODO Complete segn la documentacin
	}
}
