package uniandes.apo2h.utiles.test;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import junit.framework.TestCase;
import uniandes.apo2h.utiles.Ordenador;
import uniandes.apo2h.utiles.Ordenamientos;

/**
 * Clase que prueba el ordenador
 * @author alvar-go
 *
 */
public class OrdenadorTest extends TestCase {

	private Ordenador<Integer> ordenador;
	
	/**
	 * lista para realizar las pruebas
	 */
	private List<Integer> lista;
	
	/**
	 * Prepara el escenario de pruebas
	 */
	public void setUp()
	{
		ordenador = new Ordenador<Integer>();
		lista = new ArrayList<Integer>();
		lista.add(new Integer(10));
		lista.add(new Integer(-25));
		lista.add(new Integer(13));
		lista.add(new Integer(45));
		lista.add(new Integer(-1));
		lista.add(new Integer(-8));
		lista.add(new Integer(8));
	}
	
	/**
     * Prueba 1: Se encarga de verificar el mtodo ordenar de la clase.<br>
     * <b> Mtodos a probar: </b> <br>
     * ordenar<br>
     * <b> Casos de prueba:</b><br>
     * 1. Ordena correctamente por todos los algoritmos ascendentemente.<br>
     * 2. Ordena correctamente por todos los algoritmos descendentemente.<br>
     */
	public void testOrdenar()
	{
		for (Ordenamientos algoritmo: Ordenamientos.values()) 
		{
			Collections.shuffle(lista);
			ordenador.ordenar(algoritmo, true, new ComparadorNumeros(), lista);
			assertEquals("Error  asc en:" + algoritmo, new Integer(-25), lista.get(0));
			assertEquals("Error asc  en:" + algoritmo, new Integer(-8), lista.get(1));
			assertEquals("Error asc en:" + algoritmo, new Integer(-1), lista.get(2));
			assertEquals("Error asc  en:" + algoritmo, new Integer(8), lista.get(3));
			assertEquals("Error asc en:" + algoritmo, new Integer(10), lista.get(4));
			assertEquals("Error asc en:" + algoritmo, new Integer(13), lista.get(5));
			assertEquals("Error asc  en:" + algoritmo, new Integer(45), lista.get(6));
			
		}
		
		for (Ordenamientos algoritmo: Ordenamientos.values()) 
		{
			Collections.shuffle(lista);
			ordenador.ordenar(algoritmo, false, new ComparadorNumeros(), lista);
			assertEquals("Error desc en:" + algoritmo, new Integer(45), lista.get(0));
			assertEquals("Error desc en:" + algoritmo, new Integer(13), lista.get(1));
			assertEquals("Error desc en:" + algoritmo, new Integer(10), lista.get(2));
			assertEquals("Error desc en:" + algoritmo, new Integer(8), lista.get(3));
			assertEquals("Error desc en:" + algoritmo, new Integer(-1), lista.get(4));
			assertEquals("Error desc en:" + algoritmo, new Integer(-8), lista.get(5));
			assertEquals("Error desc en:" + algoritmo, new Integer(-25), lista.get(6));
			
		}
		
	}
	
	/**
	 * clase que solo se utilizar para probar el ordenador
	 * @author alvar-go
	 *
	 */
	private class ComparadorNumeros implements Comparator<Integer>
	{

		/**
		 * Compara dos nmeros
		 * @return	1 si el nmero o1 es mayor al nmero o2 
		 * 			-1 si el nmero o1 es menor al nmero o2
		 * 			0 si el nmero o1 es igual al nmero o2
		 */
		public int compare(Integer o1, Integer o2) {
			int comparar = o1-o2;
			if(comparar > 0)
			{
				return 1;
			}
			else if( comparar < 0 )
			{
				return -1;
			}
			else
			{
				return 0;			
			}
		}
		
	}
}
